@@ -37,7 +37,10 @@ import sys
 #pylint:disable-msg=W0401,W0611,W0614
 if sys.version_info >= (2, 7):
     from subprocess import *
+    from subprocess import MAXFD, list2cmdline, mswindows
     from subprocess import __all__
 else:
     from kitchen.pycompat27.subprocess._subprocess import *
+    from kitchen.pycompat27.subprocess._subprocess import MAXFD, \
+            list2cmdline, mswindows
     from kitchen.pycompat27.subprocess._subprocess import __all__
